package Alien::uv;
use 5.012;

our $VERSION = "1.28.0.4";

use XS::Loader;

XS::Loader::load_noboot();

1;
